@@ -5,11 +5,9 @@ Login
 Register new users, login/logout, create a "Guest user" account and convert
 existing guest accounts to normal accounts.
 """
-
-from ..conditions import approvedTermsAndConditions
-from ..conditions import checkTermsAndConditions
 from ..country import IClientCountry
 from ..utils import setLanguage
+from .conditions import approvedTermsAndConditions
 from Acquisition import aq_chain
 from Acquisition import aq_inner
 from Acquisition import aq_parent
@@ -26,19 +24,17 @@ from plonetheme.nuplone.tiles.analytics import trigger_extra_pageview
 from Products.CMFCore.utils import getToolByName
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
-from z3c.appconfig.interfaces import IAppConfig
-from z3c.appconfig.utils import asBool
+from six.moves.urllib.parse import parse_qs
+from six.moves.urllib.parse import urlencode
+from six.moves.urllib.parse import urlparse
+from six.moves.urllib.parse import urlsplit
 from z3c.saconfig import Session
-from zope import component
 
-import cgi
 import datetime
 import logging
 import os
 import re
 import six
-import urllib
-import urlparse
 
 
 log = logging.getLogger(__name__)
@@ -56,8 +52,8 @@ class Login(BrowserView):
     variation_class = "variation-dashboard"
 
     def setLanguage(self, came_from):
-        qs = urlparse.urlparse(came_from)[4]
-        params = cgi.parse_qs(qs)
+        qs = urlparse(came_from)[4]
+        params = parse_qs(qs)
         lang = params.get("language")
         if not lang:
             if IClientCountry.providedBy(self.context):
@@ -108,10 +104,9 @@ class Login(BrowserView):
             came_from = aq_parent(context).absolute_url()
 
         account = get_current_account()
-        appconfig = component.getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
-        self.allow_guest_accounts = asBool(settings.get("allow_guest_accounts", False))
-
+        self.allow_guest_accounts = api.portal.get_registry_record(
+            "euphorie.allow_guest_accounts", default=False
+        )
         lang = api.portal.get_current_language()
         self.show_whofor = False if lang in ("fr",) else True
         self.show_what_to_do = False if lang in ("fr",) else True
@@ -132,19 +127,17 @@ class Login(BrowserView):
             ):
                 self.transferGuestSession(reply.get("guest_account_id"))
                 self.login(account, bool(self.request.form.get("remember")))
-                v_url = urlparse.urlsplit(self.request.URL + "/success").path.replace(
-                    "@@", ""
-                )
+                v_url = urlsplit(self.request.URL + "/success").path.replace("@@", "")
                 trigger_extra_pageview(self.request, v_url)
 
-                if checkTermsAndConditions() and not approvedTermsAndConditions(
-                    account
-                ):
+                if api.portal.get_registry_record(
+                    "euphorie.terms_and_conditions", default=False
+                ) and not approvedTermsAndConditions(account):
                     self.request.RESPONSE.redirect(
                         "%s/terms-and-conditions?%s"
                         % (
                             context.absolute_url(),
-                            urllib.urlencode({"came_from": came_from}),
+                            urlencode({"came_from": came_from}),
                         )
                     )
                 else:
@@ -154,15 +147,15 @@ class Login(BrowserView):
 
         self.reset_password_request_url = "%s/@@reset_password_request?%s" % (
             context.absolute_url(),
-            urllib.urlencode({"came_from": came_from}),
+            urlencode({"came_from": came_from}),
         )
         self.register_url = "%s/@@register?%s" % (
             context.absolute_url(),
-            urllib.urlencode({"came_from": came_from}),
+            urlencode({"came_from": came_from}),
         )
         self.tryout_url = "%s/@@tryout?%s" % (
             context.absolute_url(),
-            urllib.urlencode({"came_from": came_from}),
+            urlencode({"came_from": came_from}),
         )
         return self.index()
 
@@ -212,9 +205,9 @@ class CreateTestSession(Tryout):
     """
 
     def __call__(self):
-        appconfig = component.getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
-        self.allow_guest_accounts = asBool(settings.get("allow_guest_accounts", False))
+        self.allow_guest_accounts = api.portal.get_registry_record(
+            "euphorie.allow_guest_accounts", default=False
+        )
         context = aq_inner(self.context)
         came_from = self.request.form.get("came_from")
         if came_from:
@@ -225,7 +218,7 @@ class CreateTestSession(Tryout):
             came_from = context.absolute_url()
         self.register_url = "%s/@@register?%s" % (
             context.absolute_url(),
-            urllib.urlencode({"came_from": came_from}),
+            urlencode({"came_from": came_from}),
         )
         setLanguage(self.request, self.context)
         if self.request.environ["REQUEST_METHOD"] == "POST":
@@ -309,7 +302,7 @@ class Register(BrowserView):
             )
         Session().add(account)
         log.info("Registered new account %s", loginname)
-        v_url = urlparse.urlsplit(self.request.URL + "/success").path.replace("@@", "")
+        v_url = urlsplit(self.request.URL + "/success").path.replace("@@", "")
         trigger_extra_pageview(self.request, v_url)
         return account
 
@@ -340,12 +333,14 @@ class Register(BrowserView):
         if not came_from:
             came_from = country_url
 
-        if checkTermsAndConditions():
+        if api.portal.get_registry_record(
+            "euphorie.terms_and_conditions", default=False
+        ):
             self.request.response.redirect(
                 "%s/terms-and-conditions?%s"
                 % (
                     self.request.client.absolute_url(),
-                    urllib.urlencode({"came_from": came_from}),
+                    urlencode({"came_from": came_from}),
                 )
             )
         else:
