@@ -22,17 +22,15 @@ from euphorie.content.utils import IToolTypesInfo
 from htmllaundry import StripMarkup
 from io import BytesIO
 from plone import api
-from plone.app.imaging.utils import getAllowedSizes
 from plone.memoize.instance import memoize
 from plone.namedfile import NamedBlobImage
 from plone.namedfile.browser import DisplayFile
 from plone.scale.scale import scaleImage
+from Products.CMFPlone.utils import getAllowedSizes
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from sqlalchemy import and_
-from z3c.appconfig.interfaces import IAppConfig
-from z3c.appconfig.utils import asBool
 from z3c.saconfig import Session
 from zope.component import getUtility
 from zope.event import notify
@@ -534,12 +532,12 @@ class IdentificationView(RiskBase):
             return
 
     def set_parameter_values(self):
-        appconfig = getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
         self.tti = getUtility(IToolTypesInfo)
         self.my_tool_type = get_tool_type(self.survey)
         self.use_existing_measures = (
-            asBool(settings.get("use_existing_measures", False))
+            api.portal.get_registry_record(
+                "euphorie.use_existing_measures", default=False
+            )
             and self.my_tool_type in self.tti.types_existing_measures
         )
 
@@ -1048,12 +1046,12 @@ class ActionPlanView(RiskBase):
         context = aq_inner(self.context)
         utils.setLanguage(self.request, self.survey, self.survey.language)
 
-        appconfig = getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
         self.tti = getUtility(IToolTypesInfo)
         self.my_tool_type = get_tool_type(self.survey)
         self.use_existing_measures = (
-            asBool(settings.get("use_existing_measures", False))
+            api.portal.get_registry_record(
+                "euphorie.use_existing_measures", default=False
+            )
             and self.my_tool_type in self.tti.types_existing_measures
         )
 
