@@ -35,12 +35,10 @@ from Products.CMFPlone import PloneLocalesMessageFactory
 from Products.Five import BrowserView
 from sqlalchemy import sql
 from sqlalchemy.orm import object_session
-from z3c.appconfig.interfaces import IAppConfig
 from z3c.form.form import EditForm
 from z3c.saconfig import Session
 from zExceptions import Unauthorized
 from zope import schema
-from zope.component import getUtility
 from zope.event import notify
 from zope.i18n import translate
 from zope.lifecycleevent import ObjectModifiedEvent
@@ -62,7 +60,7 @@ def sql_clone(obj, skip={}, session=None):
     for column in obj.__table__.columns:
         if column.key not in skip:
             getattr(obj, column.key, None)
-    params = {key: value for key, value in obj.__dict__.iteritems() if key not in skip}
+    params = {key: value for key, value in obj.__dict__.items() if key not in skip}
     clone = obj.__class__(**params)
     if session:
         session.add(clone)
@@ -277,7 +275,7 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
                 if not form.get("pq{0}.present".format(id), "") == "yes":
                     continue
                 if isinstance(answer, list):
-                    profile[id] = filter(None, (a.strip() for a in answer))
+                    profile[id] = list(filter(None, (a.strip() for a in answer)))
                     if form.get("pq{0}.multiple".format(id), "") != "yes":
                         profile[id] = profile[id][:1]
                 else:
@@ -455,9 +453,9 @@ class ContentsPreview(BrowserView):
 
     @property
     def extra_text(self):
-        appconfig = getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
-        have_extra = settings.get("extra_text_identification", False)
+        have_extra = api.portal.get_registry_record(
+            "euphorie.extra_text_identification", default=u""
+        )
         if not have_extra:
             return None
         return api.portal.translate(_(u"extra_text_identification", default=u""))
@@ -577,9 +575,9 @@ class Identification(SessionMixin, BrowserView):
 
     @property
     def extra_text(self):
-        appconfig = getUtility(IAppConfig)
-        settings = appconfig.get("euphorie")
-        have_extra = settings.get("extra_text_identification", False)
+        have_extra = api.portal.get_registry_record(
+            "euphorie.extra_text_identification", default=u""
+        )
         if not have_extra:
             return None
         lang = getattr(self.request, "LANGUAGE", "en")
@@ -934,12 +932,6 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
             ),
             now.strftime("%Y"),
         )
-        self.label_page = translate(
-            _(u"label_page", default=u"Page"), target_language=lang
-        )
-        self.label_page_of = translate(
-            _(u"label_page_of", default=u"of"), target_language=lang
-        )
         session = self.context.session
         if session.title != (
             callable(getattr(self.context, "Title", None))
@@ -982,13 +974,14 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
 
             self.add_to_risk_list(risk, module_path, has_measures=has_measures)
 
-        for key, m in modules.items():
+        for key in list(modules):
+            module = modules[key]
             if (
-                m["ok"]
-                + m["postponed"]
-                + m["risk_with_measures"]
-                + m["risk_without_measures"]
-                + m["todo"]
+                module["ok"]
+                + module["postponed"]
+                + module["risk_with_measures"]
+                + module["risk_without_measures"]
+                + module["todo"]
                 == 0
             ):
                 del modules[key]
@@ -1000,9 +993,9 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
                 (total_ok + total_with_measures) / Decimal(len(filtered_risks)) * 100
             )
         )
-        self.status = modules.values()
+        self.status = list(modules.values())
         self.status.sort(key=lambda m: m["path"])
-        self.toc = self.tocdata.values()
+        self.toc = list(self.tocdata.values())
         self.toc.sort(key=lambda m: m["path"])
 
     def add_to_risk_list(self, risk, module_path, has_measures=False):
@@ -1097,27 +1090,20 @@ class MeasuresOverview(Status):
 
         query = (
             Session.query(Module, Risk, ActionPlan)
+            .select_from(Module)
             .filter(sql.and_(Module.session == self.session, Module.profile_index > -1))
             .filter(sql.not_(SKIPPED_PARENTS))
             .filter(
                 sql.or_(MODULE_WITH_RISK_OR_TOP5_FILTER, RISK_PRESENT_OR_TOP5_FILTER)
             )
-            .join(
-                (
-                    Risk,
-                    sql.and_(
-                        Risk.path.startswith(Module.path),
-                        Risk.depth == Module.depth + 1,
-                        Risk.session == self.session,
-                    ),
-                )
-            )
-            .join((ActionPlan, ActionPlan.risk_id == Risk.id))
+            .join(Risk, Risk.parent_id == Module.id)
+            .join(ActionPlan, ActionPlan.risk_id == Risk.id)
             .order_by(
                 sql.case(value=Risk.priority, whens={"high": 0, "medium": 1}, else_=2),
                 Risk.path,
             )
         )
+
         measures = [
             t
             for t in query.all()
