@@ -11,15 +11,19 @@ from plone import api
 from z3c.saconfig import Session
 from zope.interface import alsoProvides
 
-import mock
+
+try:
+    from unittest import mock
+except ImportError:
+    import mock
 
 
 def createContainer(id, profile=False):
     from euphorie.content.interfaces import IQuestionContainer
-    from zope.interface import implements
+    from zope.interface import implementer
 
+    @implementer(IQuestionContainer)
     class Container(dict):
-        implements(IQuestionContainer)
         title = u"container"
         description = None
 
@@ -34,10 +38,10 @@ def createContainer(id, profile=False):
 
 def createRisk(id):
     from euphorie.content.risk import IRisk
-    from zope.interface import implements
+    from zope.interface import implementer
 
+    @implementer(IRisk)
     class Risk(object):
-        implements(IRisk)
         title = u"risk"
         type = "risk"
         default_probability = 0
@@ -56,10 +60,10 @@ def createRisk(id):
 def createModule(id):
     from euphorie.content.interfaces import IQuestionContainer
     from euphorie.content.module import IModule
-    from zope.interface import implements
+    from zope.interface import implementer
 
+    @implementer(IModule, IQuestionContainer)
     class Module(dict):
-        implements(IModule, IQuestionContainer)
         title = u"module"
         description = None
         optional = False
@@ -98,7 +102,7 @@ class AddToTreeTests(EuphorieIntegrationTestCase):
         self.assertEqual(len(children), 1)
 
         child = children[0]
-        self.failUnless(isinstance(child, model.Risk))
+        self.assertTrue(isinstance(child, model.Risk))
         self.assertEqual(child.title, u"risk")
         self.assertEqual(child.risk_id, "13")
         self.assertEqual(child.risk_type, "risk")
@@ -127,7 +131,7 @@ class AddToTreeTests(EuphorieIntegrationTestCase):
         children = list(self.root.children())
         self.assertEqual(len(children), 1)
         child = children[0]
-        self.failUnless(isinstance(child, model.Module))
+        self.assertTrue(isinstance(child, model.Module))
         self.assertEqual(child.title, u"container")
         self.assertEqual(child.module_id, "13")
 
@@ -428,7 +432,7 @@ class Profile_setupSession_Tests(TreeTests):
         session = view.session
         with api.env.adopt_user(user=session.account):
             view.setupSession()
-            self.failUnless(view.session is session)
+            self.assertTrue(view.session is session)
             self.assertEqual(session.hasTree(), True)
 
     def test_NewSession_SimpleProfile(self):
@@ -450,7 +454,7 @@ class Profile_setupSession_Tests(TreeTests):
         session = view.session
         with api.env.adopt_user(user=session.account):
             view.setupSession()
-            self.failUnless(view.session is session)
+            self.assertTrue(view.session is session)
             self.assertEqual(session.hasTree(), False)
 
     def test_ExistingSession_NoProfile(self):
@@ -507,7 +511,7 @@ class Profile_setupSession_Tests(TreeTests):
                 ):
                     new_session = view.setupSession()
                 view = self.makeView(survey, new_session)
-                self.failUnless(view.session is not session)
+                self.assertTrue(view.session is not session)
                 self.assertEqual(view.session.hasTree(), False)
 
     def test_ExistingSession_ProfileChangedNoLocation(self):
@@ -530,7 +534,7 @@ class Profile_setupSession_Tests(TreeTests):
                 ):
                     new_session = view.setupSession()
                 view = self.makeView(survey, new_session)
-                self.failUnless(view.session is not session)
+                self.assertTrue(view.session is not session)
                 self.assertEqual(view.session.hasTree(), False)
 
     def test_create_survey_session(self):
