@@ -8,23 +8,17 @@ A standard Solution that a user can select for a particular risk.
 
 from .. import MessageFactory as _
 from euphorie.content import utils
-from five import grok
+from plone.autoform import directives
 from plone.dexterity.content import Item
-from plone.directives import dexterity
-from plone.directives import form
 from plone.indexer import indexer
-from plonetheme.nuplone.skin.interfaces import NuPloneSkin
+from plone.supermodel import model
+from Products.CMFPlone.utils import safe_nativestring
 from zope import schema
 from zope.i18n import translate
-from zope.interface import implements
-
-import markdown
+from zope.interface import implementer
 
 
-grok.templatedir("templates")
-
-
-class ISolution(form.Schema):
+class ISolution(model.Schema):
     """A standard solution for a risk.
 
     Risk questions can have standard solutions that can be applied in
@@ -40,7 +34,7 @@ class ISolution(form.Schema):
         ),
         required=True,
     )
-    form.order_after(description="title")
+    directives.order_after(description="title")
 
     action_plan = schema.Text(
         title=_(
@@ -122,8 +116,8 @@ class ISolution(form.Schema):
     # )
 
 
+@implementer(ISolution)
 class Solution(Item):
-    implements(ISolution)
     title = _("title_common_solution", default=u"Measure")
     prevention_plan = None
     requirements = None
@@ -131,9 +125,11 @@ class Solution(Item):
 
     def Title(self):
         survey = utils.getSurvey(self)
-        return translate(
-            Solution.title, context=self.REQUEST, target_language=survey.language
-        ).encode("utf-8")
+        return safe_nativestring(
+            translate(
+                Solution.title, context=self.REQUEST, target_language=survey.language
+            )
+        )
 
 
 @indexer(ISolution)
@@ -148,41 +144,3 @@ def SearchableTextIndexer(obj):
             obj.action or "",
         ]
     )
-
-
-class View(grok.View):
-    """View name: @@nuplone-view"""
-
-    grok.context(ISolution)
-    grok.require("zope2.View")
-    grok.layer(NuPloneSkin)
-    grok.name("nuplone-view")
-    grok.template("solution_view")
-
-    def render_md(self, text):
-        return markdown.markdown(text)
-
-
-class Add(dexterity.AddForm):
-    grok.context(ISolution)
-    grok.name("euphorie.solution")
-    grok.require("euphorie.content.AddNewRIEContent")
-
-    def updateWidgets(self):
-        super(Add, self).updateWidgets()
-        self.widgets["action_plan"].mode = "hidden"
-        self.widgets["prevention_plan"].mode = "hidden"
-        self.widgets["action"].rows = 15
-
-
-class Edit(form.SchemaEditForm):
-    grok.context(ISolution)
-    grok.require("cmf.ModifyPortalContent")
-    grok.layer(NuPloneSkin)
-    grok.name("edit")
-
-    def updateWidgets(self):
-        super(Edit, self).updateWidgets()
-        self.widgets["action_plan"].mode = "hidden"
-        self.widgets["prevention_plan"].mode = "hidden"
-        self.widgets["action"].rows = 15
