@@ -15,6 +15,7 @@ from zope.interface import alsoProvides
 
 import logging
 
+
 log = logging.getLogger(__name__)
 
 
@@ -51,8 +52,7 @@ def unifiy_fields(walker):
         else:
             if count % 100 == 0:
                 log.info(
-                    "Skipped %d items, since they have already been handled."
-                    % count
+                    "Skipped %d items, since they have already been handled." % count
                 )
             if count % 1000 == 0:
                 log.info("Intermediate commit")
@@ -79,8 +79,7 @@ def unify_action_fields_in_solution_client(context):
 
 
 def get_pre_defined_measures(solutions, country):
-    """ Iterate over the Solution items on this risk.
-    """
+    """Iterate over the Solution items on this risk."""
     measures = {}
 
     for item in solutions:
@@ -123,7 +122,7 @@ def migrate_actgion_plans(context):
                     model.Account.id == model.SurveySession.account_id,
                     model.Account.account_type != "guest",
                     model.SurveySession.zodb_path == tool_path,
-                    model.SurveySession.migrated == None,
+                    model.SurveySession.migrated == None,  # noqa: E711
                 )
             )
             .order_by(model.SurveySession.zodb_path)
@@ -152,7 +151,7 @@ def migrate_actgion_plans(context):
                 elif risk_path not in risks_by_path:
                     try:
                         zodb_risk = tool.restrictedTraverse(risk_path)
-                    except:
+                    except Exception:
                         log.warning(
                             "Risk {} not found in tool {}".format(risk_path, tool_path)
                         )
@@ -173,22 +172,18 @@ def migrate_actgion_plans(context):
                 else:
                     zodb_risk = risks_by_path[risk_path]
 
-                # convert ActionPlan items that are clearly based on solutions to "standard" type
+                # convert ActionPlan items that are clearly based on solutions
+                # to "standard" type
                 if not is_custom:
                     for ap in risk.custom_measures:
                         for solution in solutions_by_path[risk_path]:
-                            if (
-                                solution.action_plan == (ap.action_plan or "").strip()
-                            ):
+                            if solution.action_plan == (ap.action_plan or "").strip():
                                 if (
-                                    (
-                                        getattr(solution, "prevention_plan", "") or ""
-                                    ).strip()
-                                    == (ap.prevention_plan or "")
-                                    and (
-                                        getattr(solution, "requirements", "") or ""
-                                    ).strip()
-                                    == (ap.requirements or "")
+                                    getattr(solution, "prevention_plan", "") or ""
+                                ).strip() == (ap.prevention_plan or "") and (
+                                    getattr(solution, "requirements", "") or ""
+                                ).strip() == (
+                                    ap.requirements or ""
                                 ):
                                     ap.plan_type = "measure_standard"
                                     ap.solution_id = solution.id
@@ -206,8 +201,12 @@ def migrate_actgion_plans(context):
                         (k, v) for (k, v) in saved_existing_measures.items()
                     ]
                 new_action_plans = []
-                already_converted_measure_ids = [x.solution_id for x in risk.in_place_standard_measures]
-                already_converted_custom_texts = [x.action for x in risk.in_place_custom_measures]
+                already_converted_measure_ids = [
+                    x.solution_id for x in risk.in_place_standard_measures
+                ]
+                already_converted_custom_texts = [
+                    x.action for x in risk.in_place_custom_measures
+                ]
                 if saved_existing_measures:
                     custom = []
                     while saved_existing_measures:
@@ -238,10 +237,3 @@ def migrate_actgion_plans(context):
         if max_tools > 0 and tool_count >= max_tools:
             log.info("Broke off after %d tools" % tool_count)
             return
-
-"""
-SELECT mig::float/total as percent_done
-FROM
-    (select (select count(*) from session join account on session.account_id=account.id where (account_type is Null or account_type!='guest') and migrated is not Null) as mig,
-    (select count(*) from session join account on session.account_id=account.id where (account_type is Null or account_type!='guest')) as total) as subq;
-"""
